#region Product support classes

namespace NihonUnisys.NeoStore.Model
{
#region Using statements

using System;
using System.Collections;
using System.Collections.Specialized;
using System.Data;
using Neo.Core;
using Neo.Core.Util;
using Neo.Framework;

#endregion

#region ProductBase

public class ProductBase : EntityObject
{
       
	protected ProductBase(System.Data.DataRow aRow, Neo.Core.ObjectContext aContext) : base(aRow, aContext)
	{
	}	
	
	public virtual System.String Name
	{
		get { return Row["Name"] as System.String; }
		set { Row["Name"] = (value != null) ? (object)value : (object)DBNull.Value; }
	}    

	public virtual System.Decimal Price
	{
		get { object v = Row["Price"]; return (System.Decimal)((v != DBNull.Value) ? v : HandleNullValueForProperty("Price")); }
		set { Row["Price"] = value; }
	}    

	public virtual Category Category
	{
		get { object fk = Row["CategoryID"]; return (fk == DBNull.Value) ? null : (Category)GetRelatedObject("Category", fk); }
		set { SetRelatedObject(value, "CategoryID", "CategoryID" ); }
	}

	public override object GetProperty(string propName)
	{
		if(propName == "Name") 
			return Name;
		if(propName == "Price") 
			return Price;
		if(propName == "Category") 
			return Category;

		return base.GetProperty(propName);
	}

}

#endregion

#region ProductTemplate

public class ProductTemplate : IFetchSpecification
{
	private IEntityMap entityMap;
	private ListDictionary queryValues;
	private int fetchLimit;
	private PropertyComparer[] sortOrderings;
	
	public ProductTemplate(IEntityMap anEntityMap)
	{
		entityMap = anEntityMap;
		queryValues = new ListDictionary();
		fetchLimit = -1;
	}

	public IEntityMap EntityMap 
	{ 
		get { return entityMap; } 
	}

	public Qualifier Qualifier
	{
		get { return Qualifier.FromPropertyDictionary(queryValues); }
	}
	
	public Int32 FetchLimit
	{
		get { return fetchLimit; }
		set { fetchLimit = value; }
	}
	
	public PropertyComparer[] SortOrderings
	{
		get { return sortOrderings; }
		set { sortOrderings = value; }
	}
	
	public System.String Name
	{
		get { return (System.String)queryValues["Name"]; }
		set { queryValues["Name"] = value; }
	}

	public System.Decimal Price
	{
		get { return (System.Decimal)queryValues["Price"]; }
		set { queryValues["Price"] = value; }
	}

	public Category Category
	{
		get { return (Category)queryValues["Category"]; }
		set { queryValues["Category"] = value; }
	}

}

#endregion

#region ProductCollections

#region ProductList

//-------- Typed Collections ----------------------------------------------

public class ProductList : ObjectListBase
{
	public ProductList()
	{
	}

	public ProductList(IList list)
	{
		((ArrayList)InnerList).AddRange(list);
	}

	public Product this[int index]
	{
		get { return (Product)InnerList[index]; }
	}

	public int Add(Product newProduct)
	{
		return base.Add(newProduct);
	}

	public void Remove(Product existingProduct)
	{
		base.Remove(existingProduct);
	}

	public bool Contains(Product existingProduct)
	{
		return base.Contains(existingProduct);
	}

	public int IndexOf(Product existingProduct)
	{
		return base.IndexOf(existingProduct);
	}
	
	public ProductList Find(string qualifierFormat, params object[] parameters)
	{
		ProductList resultSet = new ProductList();
		base.Find(resultSet, qualifierFormat, parameters);
		return resultSet;
	}

	public new Product FindUnique(string qualifierFormat, params object[] parameters)
	{
		return (Product)base.FindUnique(qualifierFormat, parameters);
	}
	
	public new Product FindFirst(string qualifierFormat, params object[] parameters)
	{
		return (Product)base.FindFirst(qualifierFormat, parameters);
	}
	
}

#endregion 

#region ProductRelation

public class ProductRelation : ObjectRelationBase
{
	public ProductRelation(IEntityObject eo, string aRelation) : base(eo, aRelation)
	{
	}

	public Product this[int index]
	{
		get { return (Product)InnerList[index]; }
	}

	public int Add(Product newProduct)
	{
		return base.Add(newProduct);
	}

	public void Remove(Product existingProduct)
	{
		base.Remove(existingProduct);
	}

	public bool Contains(Product existingProduct)
	{
		return base.Contains(existingProduct);
	}

	public int IndexOf(Product existingProduct)
	{
		return base.IndexOf(existingProduct);
	}

	public ProductList GetReadOnlyList()
	{
		ProductList resultSet = new ProductList();
		base.CopyToListAndMakeReadOnly(resultSet);
		return resultSet;
	}
	
	public ProductList GetSortedList(string propName, SortDirection dir)
	{
		ProductList resultSet = new ProductList();
		base.CopyToListAndSort(resultSet, propName, dir);
		return resultSet;
	}

	public ProductList Find(string qualifierFormat, params object[] parameters)
	{
		ProductList resultSet = new ProductList();
		base.Find(resultSet, qualifierFormat, parameters);
		return resultSet;
	}

	public new Product FindUnique(string qualifierFormat, params object[] parameters)
	{
		return (Product)base.FindUnique(qualifierFormat, parameters);
	}
	
	public new Product FindFirst(string qualifierFormat, params object[] parameters)
	{
		return (Product)base.FindFirst(qualifierFormat, parameters);
	}

}

#endregion

#endregion

#region ProductFactory

public class ProductFactory : Neo.Framework.ObjectFactory
{
	public ProductFactory(ObjectContext context) : base(context, typeof(Product))
	{
	}

	public Product CreateObject()
	{
		return (Product)base.CreateObject(null);
	}

	public Product FindObject(System.Int32 arg0)
	{
		return (Product)base.FindObject(new object[] { arg0 } );
	}

	public new ProductList FindAllObjects()
	{
		ProductList c = new ProductList();
		foreach(Product eo in base.FindAllObjects())
			c.Add(eo);
		return c;
	}
	
	public ProductTemplate GetQueryTemplate()
	{
		return new ProductTemplate(EntityMap);
	}
	
	public ProductList Find(ProductTemplate template)
	{
		ProductList c = new ProductList();
		foreach(Product eo in base.Find(template))
			c.Add(eo);
		return c;
	}

	public ProductList Find(FetchSpecification fetchSpecification)
	{
		ProductList c = new ProductList();
		foreach(Product eo in base.Find(fetchSpecification))
			c.Add(eo);
		return c;
	}
	
	public new ProductList Find(string qualifierFormat, params object[] parameters)
	{
		ProductList c = new ProductList();
		foreach(Product eo in base.Find(qualifierFormat, parameters))
			c.Add(eo);
		return c;
	}

	public new ProductList FindWithLimit(int limit, string qualifierFormat, params object[] parameters)
	{
		ProductList c = new ProductList();
		foreach(Product eo in base.Find(qualifierFormat, parameters))
			c.Add(eo);
		return c;
	}
	
	public new Product FindFirst(string qualifierFormat, params object[] parameters)
	{
		return (Product)base.FindFirst(qualifierFormat, parameters);
	}

	public new Product FindUnique(string qualifierFormat, params object[] parameters)
	{
		return (Product)base.FindUnique(qualifierFormat, parameters);
	}	
	
}

#endregion

#region ProductEntityMap

internal class ProductMap : EntityMap
{
    private static readonly string[] pkcolumns = { "ProductID" };
    private static readonly string[] columns = { "ProductID", "CategoryID", "Name", "Price" };
    private static readonly string[] attributes = { "Productid", "Categoryid", "Name", "Price" };
    private static readonly string[] relations = { "Category" };

    public override System.Type ObjectType
    {
        get { return typeof(Product); }
    }
    
    public override string TableName
    {
        get { return "Product"; }
    }
    
    public override string[] PrimaryKeyColumns
    {
        get { return pkcolumns; }
    }

    public override string[] Columns
    {
        get { return columns; }
    }

    public override string[] Attributes
    {
        get { return attributes; }
    }

    public override string[] Relations
    {
        get { return relations; }
    }

  	protected override IDictionary GetRelationInfos()
    {
    	IDictionary infos = new Hashtable(1);
  		infos.Add("Category", new RelationInfo(Factory, typeof(Category), typeof(Product), "CategoryID", "CategoryID"));
		return infos;    	
    }
    
	public override IPkInitializer GetPkInitializer()
	{
		return new NativePkInitializer();
	}
    
    public override IEntityObject CreateInstance(DataRow row, ObjectContext context) /* #custom# overridden */
    {
		if(ConcreteObjectType != ObjectType)
			return base.CreateInstance(row, context);
		return new Product(row, context);
	}
    
    protected override void WriteBasicSchema(DataTable table)
    {
		DataColumn		c;
		
		c = table.Columns.Add("ProductID", typeof(System.Int32));
		c.Unique = true;
		c.AutoIncrement = true; c.AutoIncrementSeed = c.AutoIncrementStep = -1;
		c = table.Columns.Add("CategoryID", typeof(System.Int32));
		c = table.Columns.Add("Name", typeof(System.String));
		c = table.Columns.Add("Price", typeof(System.Decimal));
		table.PrimaryKey = new DataColumn[] { table.Columns["ProductID"] };
	}
	
	protected override void WriteRelations(DataTable table)
	{
		DataRelation r;
		
		if(table.DataSet.Relations["Category*Product.CategoryID"] == null)
		{
			r = table.DataSet.Relations.Add("Category*Product.CategoryID", 
					table.DataSet.Tables["Category"].Columns["CategoryID"],
					table.DataSet.Tables["Product"].Columns["CategoryID"]);
			r.ChildKeyConstraint.UpdateRule = Rule.Cascade;
			r.ChildKeyConstraint.DeleteRule = Rule.Cascade;
		}
	}
}

#endregion

}

#endregion

#region Category support classes

namespace NihonUnisys.NeoStore.Model
{
#region Using statements

using System;
using System.Collections;
using System.Collections.Specialized;
using System.Data;
using Neo.Core;
using Neo.Core.Util;
using Neo.Framework;

#endregion

#region CategoryBase

public class CategoryBase : EntityObject
{
	public readonly ProductRelation Products;
       
	protected CategoryBase(System.Data.DataRow aRow, Neo.Core.ObjectContext aContext) : base(aRow, aContext)
	{
		Products = new ProductRelation(this, "Products");
	}	
	
	public virtual System.String Name
	{
		get { return Row["Name"] as System.String; }
		set { Row["Name"] = (value != null) ? (object)value : (object)DBNull.Value; }
	}    

	public override object GetProperty(string propName)
	{
		if(propName == "Name") 
			return Name;

		return base.GetProperty(propName);
	}

}

#endregion

#region CategoryTemplate

public class CategoryTemplate : IFetchSpecification
{
	private IEntityMap entityMap;
	private ListDictionary queryValues;
	private int fetchLimit;
	private PropertyComparer[] sortOrderings;
	
	public CategoryTemplate(IEntityMap anEntityMap)
	{
		entityMap = anEntityMap;
		queryValues = new ListDictionary();
		fetchLimit = -1;
	}

	public IEntityMap EntityMap 
	{ 
		get { return entityMap; } 
	}

	public Qualifier Qualifier
	{
		get { return Qualifier.FromPropertyDictionary(queryValues); }
	}
	
	public Int32 FetchLimit
	{
		get { return fetchLimit; }
		set { fetchLimit = value; }
	}
	
	public PropertyComparer[] SortOrderings
	{
		get { return sortOrderings; }
		set { sortOrderings = value; }
	}
	
	public System.String Name
	{
		get { return (System.String)queryValues["Name"]; }
		set { queryValues["Name"] = value; }
	}

}

#endregion

#region CategoryCollections

#region CategoryList

//-------- Typed Collections ----------------------------------------------

public class CategoryList : ObjectListBase
{
	public CategoryList()
	{
	}

	public CategoryList(IList list)
	{
		((ArrayList)InnerList).AddRange(list);
	}

	public Category this[int index]
	{
		get { return (Category)InnerList[index]; }
	}

	public int Add(Category newCategory)
	{
		return base.Add(newCategory);
	}

	public void Remove(Category existingCategory)
	{
		base.Remove(existingCategory);
	}

	public bool Contains(Category existingCategory)
	{
		return base.Contains(existingCategory);
	}

	public int IndexOf(Category existingCategory)
	{
		return base.IndexOf(existingCategory);
	}
	
	public CategoryList Find(string qualifierFormat, params object[] parameters)
	{
		CategoryList resultSet = new CategoryList();
		base.Find(resultSet, qualifierFormat, parameters);
		return resultSet;
	}

	public new Category FindUnique(string qualifierFormat, params object[] parameters)
	{
		return (Category)base.FindUnique(qualifierFormat, parameters);
	}
	
	public new Category FindFirst(string qualifierFormat, params object[] parameters)
	{
		return (Category)base.FindFirst(qualifierFormat, parameters);
	}
	
}

#endregion 

#region CategoryRelation

public class CategoryRelation : ObjectRelationBase
{
	public CategoryRelation(IEntityObject eo, string aRelation) : base(eo, aRelation)
	{
	}

	public Category this[int index]
	{
		get { return (Category)InnerList[index]; }
	}

	public int Add(Category newCategory)
	{
		return base.Add(newCategory);
	}

	public void Remove(Category existingCategory)
	{
		base.Remove(existingCategory);
	}

	public bool Contains(Category existingCategory)
	{
		return base.Contains(existingCategory);
	}

	public int IndexOf(Category existingCategory)
	{
		return base.IndexOf(existingCategory);
	}

	public CategoryList GetReadOnlyList()
	{
		CategoryList resultSet = new CategoryList();
		base.CopyToListAndMakeReadOnly(resultSet);
		return resultSet;
	}
	
	public CategoryList GetSortedList(string propName, SortDirection dir)
	{
		CategoryList resultSet = new CategoryList();
		base.CopyToListAndSort(resultSet, propName, dir);
		return resultSet;
	}

	public CategoryList Find(string qualifierFormat, params object[] parameters)
	{
		CategoryList resultSet = new CategoryList();
		base.Find(resultSet, qualifierFormat, parameters);
		return resultSet;
	}

	public new Category FindUnique(string qualifierFormat, params object[] parameters)
	{
		return (Category)base.FindUnique(qualifierFormat, parameters);
	}
	
	public new Category FindFirst(string qualifierFormat, params object[] parameters)
	{
		return (Category)base.FindFirst(qualifierFormat, parameters);
	}

}

#endregion

#endregion

#region CategoryFactory

public class CategoryFactory : Neo.Framework.ObjectFactory
{
	public CategoryFactory(ObjectContext context) : base(context, typeof(Category))
	{
	}

	public Category CreateObject()
	{
		return (Category)base.CreateObject(null);
	}

	public Category FindObject(System.Int32 arg0)
	{
		return (Category)base.FindObject(new object[] { arg0 } );
	}

	public new CategoryList FindAllObjects()
	{
		CategoryList c = new CategoryList();
		foreach(Category eo in base.FindAllObjects())
			c.Add(eo);
		return c;
	}
	
	public CategoryTemplate GetQueryTemplate()
	{
		return new CategoryTemplate(EntityMap);
	}
	
	public CategoryList Find(CategoryTemplate template)
	{
		CategoryList c = new CategoryList();
		foreach(Category eo in base.Find(template))
			c.Add(eo);
		return c;
	}

	public CategoryList Find(FetchSpecification fetchSpecification)
	{
		CategoryList c = new CategoryList();
		foreach(Category eo in base.Find(fetchSpecification))
			c.Add(eo);
		return c;
	}
	
	public new CategoryList Find(string qualifierFormat, params object[] parameters)
	{
		CategoryList c = new CategoryList();
		foreach(Category eo in base.Find(qualifierFormat, parameters))
			c.Add(eo);
		return c;
	}

	public new CategoryList FindWithLimit(int limit, string qualifierFormat, params object[] parameters)
	{
		CategoryList c = new CategoryList();
		foreach(Category eo in base.Find(qualifierFormat, parameters))
			c.Add(eo);
		return c;
	}
	
	public new Category FindFirst(string qualifierFormat, params object[] parameters)
	{
		return (Category)base.FindFirst(qualifierFormat, parameters);
	}

	public new Category FindUnique(string qualifierFormat, params object[] parameters)
	{
		return (Category)base.FindUnique(qualifierFormat, parameters);
	}	
	
}

#endregion

#region CategoryEntityMap

internal class CategoryMap : EntityMap
{
    private static readonly string[] pkcolumns = { "CategoryID" };
    private static readonly string[] columns = { "CategoryID", "Name" };
    private static readonly string[] attributes = { "Categoryid", "Name" };
    private static readonly string[] relations = { "Products" };

    public override System.Type ObjectType
    {
        get { return typeof(Category); }
    }
    
    public override string TableName
    {
        get { return "Category"; }
    }
    
    public override string[] PrimaryKeyColumns
    {
        get { return pkcolumns; }
    }

    public override string[] Columns
    {
        get { return columns; }
    }

    public override string[] Attributes
    {
        get { return attributes; }
    }

    public override string[] Relations
    {
        get { return relations; }
    }

  	protected override IDictionary GetRelationInfos()
    {
    	IDictionary infos = new Hashtable(1);
  		infos.Add("Products", new RelationInfo(Factory, typeof(Category), typeof(Product), "CategoryID", "CategoryID"));
		return infos;    	
    }
    
	public override IPkInitializer GetPkInitializer()
	{
		return new NativePkInitializer();
	}
    
    public override IEntityObject CreateInstance(DataRow row, ObjectContext context) /* #custom# overridden */
    {
		if(ConcreteObjectType != ObjectType)
			return base.CreateInstance(row, context);
		return new Category(row, context);
	}
    
    protected override void WriteBasicSchema(DataTable table)
    {
		DataColumn		c;
		
		c = table.Columns.Add("CategoryID", typeof(System.Int32));
		c.Unique = true;
		c.AutoIncrement = true; c.AutoIncrementSeed = c.AutoIncrementStep = -1;
		c = table.Columns.Add("Name", typeof(System.String));
		table.PrimaryKey = new DataColumn[] { table.Columns["CategoryID"] };
	}
	
	protected override void WriteRelations(DataTable table)
	{
		DataRelation r;
		
 		if(table.DataSet.Relations["Category*Product.CategoryID"] == null)
		{
			r = table.DataSet.Relations.Add("Category*Product.CategoryID", 
					table.DataSet.Tables["Category"].Columns["CategoryID"],
					table.DataSet.Tables["Product"].Columns["CategoryID"]);
			r.ChildKeyConstraint.UpdateRule = Rule.Cascade;
			r.ChildKeyConstraint.DeleteRule = Rule.Cascade;
		}
	}
}

#endregion

}

#endregion

